@@ -1,5 +1,4 @@
-"""The :py:mod:`postgres` Python library is a high-value abstraction over the
-`psycopg2`_ database driver.
+"""This is a PostgreSQL client library for humans.
 
 
 Installation
@@ -9,7 +8,7 @@ Installation
 
     $ pip install postgres
 
-:py:mod:`postgres` requires :py:mod:`psycopg2` version 2.5 or higher.
+:py:mod:`postgres` requires `psycopg2`_ version 2.5 or higher.
 
 We `test <https://travis-ci.org/gittip/postgres.py>`_ against Python 2.6, 2.7,
 3.2, and 3.3. We don't yet have a testing matrix for different versions of
@@ -178,7 +177,7 @@ from psycopg2.extras import register_composite, CompositeCaster
 from psycopg2.pool import ThreadedConnectionPool as ConnectionPool
 
 
-__version__ = '2.1.1'
+__version__ = '2.1.2'
 
 
 # A Helper
@@ -662,7 +661,8 @@ class Postgres(object):
 
         :param ModelSubclass: the :py:class:`~postgres.orm.Model` subclass to
             unregister
-        :raises: :py:exc:`~postgres.NotRegistered`
+        :raises: :py:exc:`~postgres.NotAModel`,
+            :py:exc:`~postgres.NotRegistered`
 
         If :py:class:`ModelSubclass` is registered for multiple types, it is
         unregistered for all of them.
@@ -690,7 +690,8 @@ class Postgres(object):
             types
 
         :rettype: string
-        :raises: :py:exc:`~postgres.NotRegistered`
+        :raises: :py:exc:`~postgres.NotAModel`,
+            :py:exc:`~postgres.NotRegistered`
 
         """
         self._validate_model_subclass(ModelSubclass)
